; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;
[Command]
name = "Au"
command = ~D, DF, F, D, DF, F, a
time = 20

[command]
name = "Au Frenzy"
command = ~D, DF, F, D, DF, F, b
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "blocking"
command = $F,x
time = 3

[Command]
name = "blocking" ;Same name as above (buttons in opposite order)
command = x,$F
time = 3

[Command]
name = "flying_dance"
command = ~F, D, DF, a

[Command]
name = "flying_dance2"
command = ~F, D, DF, b

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCB_x"
command = ~F, DF, D, DB, B, x

[Command]
name = "QCB_y"
command = ~F, DF, D, DB, B, y

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_ab"
command = ~D, DF, F, a+b

[Command]
name = "realbeatfinish"
command = ~D, DF, F, ~a

[Command]
name = "realbeatfinish"
command = ~D, DF, F, ~b

[Command]
name = "realbeatfinish"
command = ~D, ~DF, F, ~a

[Command]
name = "realbeatfinish"
command = ~D, ~DF, F, ~b

[Command]
name = "realbeatfinish"
command = ~D, ~DF, ~F, ~a

[Command]
name = "realbeatfinish"
command = ~D, ~DF, ~F, ~b

[Command]
name = "realbeatfinish"
command = D, ~DF, F, ~a

[Command]
name = "realbeatfinish"
command = D, ~DF, F, ~b

[Command]
name = "realbeatfinish"
command = ~D, ~DF, ~F, ~a

[Command]
name = "realbeatfinish"
command = ~D, ~DF, ~F, ~b

[Command]
name = "realbeatfinish"
command = D, DF, ~F, ~a

[Command]
name = "realbeatfinish"
command = D, DF, ~F, ~b

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "gc";Required (do not remove)
command = y+b
time = 1

[Command]
name = "evade";Required (do not remove)
command = x+a
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "DU"
command = $D, $U
time = 2

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Au Frenzy
[State -1, Au Frenzy]
type = ChangeState
value = 3020
triggerall = command = "Au Frenzy"
triggerall = power >= 2000
triggerall = stateno != [1300,1310]
trigger1 = Statetype != A
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact
;---------------------------------------------------------------------------
;Au
[State -1, Au]
type = ChangeState
value = 3000
triggerall = command = "Au"
triggerall = power >= 1000
triggerall = stateno != [1300,1310]
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking
var(1) = 1

;---------------------------------------------------------------------------
;Light Parafuso
[State -1, Light Parafuso]
type = ChangeState
value = 1000
triggerall = command = "QCB_a"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [200,435]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Parafuso
[State -1, Strong Parafuso]
type = ChangeState
value = 1010
triggerall = command = "QCB_b"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [200,435]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Light Flying Dance
[State -1, Light Flying Dance]
type = ChangeState
value = 1100
triggerall = command = "flying_dance"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [200,435]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Flying Dance
[State -1, Strong Flying Dance]
type = ChangeState
value = 1110
triggerall = command = "flying_dance2"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [200,435]
trigger2 = movecontact

;===========================================================================
;Real Beat
[State -1, Real Beat]
type=changestate
value= 1300
triggerall= (command="a" || command="b") && var(45)>=3
triggerall= roundstate=2 && statetype!=A && statetype!=C
trigger1= ctrl || stateno=40 || stateno=52 || (stateno=[100,101])
trigger2 = stateno = [200,435]
trigger2 = movecontact
trigger3 = (StateType = S) && (MoveContact) && (Var(56) > 0)

;===========================================================================
;Real Beat Finisher
[State -1, Finisher Real Beat]
type = ChangeState
value = 1320
triggerAll = command = "realbeatfinish"
triggerAll = RoundState = 2 && StateType != A
trigger1 = StateNo = 1305
trigger1 = animelemtime(2) = 0 || animelemtime(4) = 0 || animelemtime(6) = 0
;---------------------------------------------------------------------------
;Bencao (light)
[State -1, Bencao]
type = ChangeState
value = 1200
triggerall = command = "QCF_x"
triggerall = !numhelper(1250)
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [200,435]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Bencao (strong)
[State -1, Bencao Strong]
type = ChangeState
value = 1210
triggerall = command = "QCF_y"
triggerall = !numhelper(1250)
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [200,435]
trigger2 = movecontact
;---------------------------------------------------------------------------
;Queixada
[State -1, Queixada]
Type = ChangeState
triggerall = var(10) >= 2 && !numhelper(1600) && stateno != 1400
Trigger1 = StateType != A && (ctrl || stateno = 100)
trigger2 = stateno = [200,435]
trigger2 = movecontact
value = 1400

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
triggerall = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
;----------------------------------------------------------------------------
;Roll Fwd
[State -1, Roll Back]
type = ChangeState
value = 706
triggerall = var(56) = 0
triggerall = command = "evade"
triggerall = command = "holdback"
trigger1 = statetype != A
trigger1= ctrl || (stateno=[100,101]); "Has control or is running"
;trigger2 = stateno = 205
;trigger2 = time > 6
;----------------------------------------------------------------------------
;Roll Fwd
[State -1, Roll Fwd]
type = ChangeState
value = 705
triggerall = var(56) = 0
triggerall = command = "evade"
triggerall = command = "holdfwd"
trigger1 = statetype != A
trigger1= ctrl || (stateno=[100,101]); "Has control or is running"
;trigger2 = stateno = 205
;trigger2 = time > 6
;-----------------------------------------------
;Guard Cancel
[State -1, farts]
type = changestate
value = 1240
triggerall = command = "gc"
trigger1 = Time <= 6
trigger1 = Statetype != A
trigger1 = Stateno = 151 || Stateno = 150
trigger1 = power >= 1000
;--------------------------------------------------
;Crush Attack
[State -1, farts]
type = changestate
value = 1260
triggerall = command = "gc"
trigger1 = Statetype != A
trigger1 = Stateno != 151 || Stateno != 150
trigger1 = ctrl
;--------------------------------------------------
;Evade
[State -1, Evade]
type = ChangeState
value = 700
triggerall = var(56) = 0
triggerall = command = "evade"
triggerall = command != "holdfwd" || command != "holdback"
trigger1 = statetype != A
trigger1= ctrl

;---------------------------------------------------------------------------
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype != C && statetype != A
triggerall = ctrl
triggerall = stateno != 100 && stateno != 10
trigger1 = command = "holdfwd"
trigger1 = p2dist X < 49
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2dist X < 49
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;-------------------------------------------------------
[State -1, SJ]
type = ChangeState
value = ifelse((var(3)=2),43,42)
triggerall = !movetype = A
triggerall = !movetype = H
triggerall = prevstateno != [200,650]
trigger1 = command = "DU"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = StateNo = 100 && (Command = "holdfwd")
trigger2 = command = "holdup"
trigger2 = statetype != A
;===========================================================================
;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype != A 
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype != A 
trigger1 = ctrl

;---------------------------------------------------------------------------
;Breakdancing
[State -1, Crouching Light Kick]
type = ChangeState
value = 435
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = command = "holdfwd"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,245]
trigger3 = stateno = [400,440]
trigger3 = stateno != 435

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = statetype != A 
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = statetype != A 
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = ifelse((vel x !=0),615,610)
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = ifelse((vel x != 0),645,640)
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
;---------------------------------------------------------------------------
;Overhead Light Punch
[State -1, Overhead Light Punch]
type = ChangeState
value = 217
triggerall = command = "x" && command = "holdfwd"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1= ctrl
trigger2 = stateno = 100 || stateno = 101
trigger3 = stateno = [200,450]
trigger3 = stateno != 217
trigger3 = movecontact
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200 
triggerall = P2BodyDist X >= 30
triggerall = command = "x"
triggerall = statetype != A
triggerall = command != "holddown"
trigger1= ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Close Stand Light Punch
;p`
[State -1, Close Stand Light Punch]
type = ChangeState
value = 205
triggerall = P2BodyDist X <= 30
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1= ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = P2BodyDist X >= 30
triggerall = command = "y"
;triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Close Stand Strong Punch
[State -1, Close Stand Strong Punch]
type = ChangeState
value = 215
triggerall = P2BodyDist X <= 30
triggerall = command = "y"
;triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = P2BodyDist X >= 30
triggerall = command = "a"
;triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Close Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 235
triggerall = P2BodyDist X <= 30
triggerall = command = "a"
;triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = P2BodyDist X >= 40
triggerall = command = "b"; && command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Close Standing Strong Kick
[State -1, Close Standing Strong Kick]
type = ChangeState
value = 245
triggerall = command = "b"; && command != "holddown"
triggerall = P2BodyDist X <= 40
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 100 || stateno = 101

